from pydantic import BaseModel
from typing import Optional, Union, Dict

class ObjectResult(BaseModel):
    object: Dict
    
class DeleteResult(BaseModel):
    id: Union[str, int]


class ResultToken(BaseModel):
    token: Optional[str] = None
    refreshToken: Optional[str] = None

class SearchResult(BaseModel):
        items: Optional[list[ObjectResult]] = []
        total: int
        totalPages: int
        page: int
        size: int
        nextPage: Optional[int] = None
        previousPage: Optional[int] = None

class ResponseDTO(BaseModel):
    resultToken: Optional[ResultToken] = None
    resultObject: Union[SearchResult,DeleteResult,ObjectResult,SearchResult, None] = None
    message:  Optional[str] = None
    status: Optional[str] = None
    isError: Optional[bool] = False


from setuptools import setup, find_packages

setup(
    name='arianeDevs',
    version='0.1.5',
    description='arianeDevs',
    author='alandevcol',
    author_email='alandevcol@gmail.com',
    url='https://github.com/alandevcol/arianeDevs',
    packages=find_packages(),
    install_requires=[
        "pydantic>=2.0.0",
    ],
    include_package_data=False,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
    ],
)
